@@ -17,7 +17,6 @@ from tune_the_model.resource import (
 
 log = logging.getLogger(__name__)
 
-
 MINIMUM_ENTRIES = 32
 
 
@@ -235,12 +234,7 @@ class TuneTheModel():
         return cls.from_dict(r)
 
     @classmethod
-    def create(cls, data: dict) -> 'TuneTheModel':
-        r = TuneTheModelAPI.create(data)
-        return cls.from_dict(r)
-
-    @classmethod
-    def create_classifier(cls, filename: str, train_iters: int = None, num_classes: int = None):
+    def create_classifier(cls, filename: str = None, train_iters: int = None, num_classes: int = None):
         model = {"model_type": "classifier"}
 
         model["model_params"] = {}
@@ -249,16 +243,16 @@ class TuneTheModel():
         if num_classes:
             model["model_params"]["num_classes"] = num_classes
 
-        return cls.load_or_create(filename, model)
+        return cls.create(model, filename)
 
     @classmethod
-    def create_generator(cls, filename: str, train_iters: int = None):
+    def create_generator(cls, filename: str = None, train_iters: int = None):
         model = {"model_type": "generator"}
 
         if train_iters:
             model["model_params"] = {"train_iters": train_iters}
 
-        return cls.load_or_create(filename, model)
+        return cls.create(model, filename)
 
     @classmethod
     def models(cls) -> List['TuneTheModel']:
@@ -269,21 +263,24 @@ class TuneTheModel():
         ]
 
     @classmethod
-    def load(cls, filename: str) -> 'TuneTheModel':
-        with open(filename, "r") as fl:
-            data = json.load(fl)
-            return cls.from_dict(data)
+    def load_model(cls, filename: str) -> 'TuneTheModel':
+        if os.path.isfile(filename):
+            with open(filename, "r") as fl:
+                data = json.load(fl)
+                return cls.from_dict(data)
+
+        raise TuneTheModelException(f"No such file named {filename}")
 
     @classmethod
-    def load_or_create(cls, filename: str, data: dict) -> 'TuneTheModel':
-        if os.path.isfile(filename):
-            model = cls.load(filename)
-            if model.type != data["model_type"]:
-                raise TuneTheModelException(
-                    f"Model in the file is not {data['model_type']}")
-        else:
-            model = cls.create(data)
+    def create(cls, data: dict, filename: str = None) -> 'TuneTheModel':
+        response = TuneTheModelAPI.create(data)
+        model = cls.from_dict(response)
+
+        if filename:
+            if os.path.isfile(filename):
+                log.warning(f"File {filename} already exists and will be overwriten")
             model.save(filename)
+
         return model
 
     @inited
@@ -410,7 +407,8 @@ class TuneTheModel():
     @inited
     def bind(self, train_file: TuneTheModelFile, validate_file: TuneTheModelFile) -> 'TuneTheModel':
         TuneTheModelAPI.bind(self._id, data={
-                         "train_file": train_file.id, "validate_file": validate_file.id})
+            "train_file": train_file.id, "validate_file": validate_file.id
+        })
         self._update_status()
         return self
 
@@ -436,7 +434,7 @@ class TuneTheModel():
 
 
 def tune_generator(
-    filename: str,
+    filename: str = None,
     train_X: Union[list, Series, ndarray, None] = None,
     train_y: Union[list, Series, ndarray, None] = None,
     validate_X: Union[list, Series, ndarray, None] = None,
